@@ -4,13 +4,14 @@ from django.conf import settings
 # process
 TESTED_APPS_VAR_NAME = getattr(settings, 'TESTED_APPS_VAR_NAME', 'TESTS_APPS')
 
-# Modules not to trace
-COVERAGE_OMIT_MODULES = getattr(settings, 'COVERAGE_OMIT_MODULES', ['*test*'])
+# Coverage settings
+COVERAGE_OMIT_MODULES = getattr(settings, 'COVERAGE_OMIT_MODULES', [])
 COVERAGE_EXCLUDE_PATTERNS = getattr(settings, 'COVERAGE_EXCLUDE_PATTERNS', [
     r'def __unicode__\(self\):',
     r'def __str__\(self\):',
     r'def get_absolute_url\(self\):',
-    r'from .* import .*', 'import .*',
+    r'from .* import .*',
+    r'import .*',
 ])
 
 # Determines whether the apps to be included in the coverage report
